/**
This file is part of a jTEM project.
All jTEM projects are licensed under the FreeBSD license 
or 2-clause BSD license (see http://www.opensource.org/licenses/bsd-license.php). 

Copyright (c) 2005-2010, Technische Universität Berlin, jTEM
All rights reserved.

Redistribution and use in source and binary forms, with or without modification, 
are permitted provided that the following conditions are met:

-	Redistributions of source code must retain the above copyright notice, 
	this list of conditions and the following disclaimer.

-	Redistributions in binary form must reproduce the above copyright notice, 
	this list of conditions and the following disclaimer in the documentation 
	and/or other materials provided with the distribution.
 
THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS 
BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, 
OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT 
OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, 
STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING 
IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY 
OF SUCH DAMAGE.
**/

package de.jtem.function.complex;

import de.jtem.function.Domain;
import de.jtem.mfc.field.Complex;


public class ComplexFunction {

    private interface OnSubsetOfIntegers {

        /** returns the value of this function at <code>j</code>. */

        public Complex valueAt(int j);
    }

    private interface OnSubsetOfReals {

        /** returns the value of this function at <code>t</code>. */

        public Complex valueAt(double t);
    }

    private interface OnSubsetOfIntegersCrossIntegers {

        /** returns the value of this function at <code>i,j</code>. */

        public Complex valueAt(int i, int j);
    }

    private interface OnSubsetOfIntegersCrossReals {

        /** returns the value of this function at <code>i,t</code>. */

        public Complex valueAt(int i, double t);
    }

    private interface OnSubsetOfRealsCrossIntegers {

        /** returns the value of this function at <code>s,j</code>. */

        public Complex valueAt(double s, int j);
    }

    private interface OnSubsetOfRealsCrossReals {

        /** returns the value of this function at <code>s,t</code>. */

        public Complex valueAt(double s, double t);
    }

    private interface OnSubsetOfIntegersCrossIntegersCrossIntegers {

        /** returns the value of this function at <code>i,j,k</code>. */

        public Complex valueAt(int i, int j, int k);
    }

    private interface OnSubsetOfRealsCrossRealsCrossReals {

        /** returns the value of this function at <code>s,t,u</code>. */

        public Complex valueAt(double s, double t, double u);
    }

    public interface OnIndex
        extends OnSubsetOfIntegers, Domain.OnIndex {}

    public interface OnNonNegativeIntegers
        extends OnSubsetOfIntegers, Domain.OnNonNegativeIntegers {}

    public interface OnIntegers
        extends OnNonNegativeIntegers, Domain.OnIntegers {}

    public interface PeriodicOnIntegers
        extends OnIntegers, Domain.PeriodicOnIntegers {}

    public interface OnInterval
        extends OnSubsetOfReals, Domain.OnInterval {}

    public interface OnNonNegativeReals
        extends OnSubsetOfReals, Domain.OnNonNegativeReals {}

    public interface OnReals
        extends OnNonNegativeReals, Domain.OnReals {}

    public interface PeriodicOnReals
        extends OnReals, Domain.PeriodicOnReals {}

    public interface OnIndexCrossIndex
        extends OnSubsetOfIntegersCrossIntegers, Domain.OnIndexCrossIndex {}

    public interface OnIndexCrossIntegers
        extends OnSubsetOfIntegersCrossIntegers, Domain.OnIndexCrossIntegers {}

    public interface PeriodicOnIndexCrossIntegers
        extends OnSubsetOfIntegersCrossIntegers,
        Domain.PeriodicOnIndexCrossIntegers {}

    public interface OnIndexCrossInterval
        extends OnSubsetOfIntegersCrossReals, Domain.OnIndexCrossInterval {}

    public interface OnIndexCrossReals
        extends OnSubsetOfIntegersCrossReals, Domain.OnIndexCrossReals {}

    public interface PeriodicOnIndexCrossReals
        extends OnSubsetOfIntegersCrossReals,
        Domain.PeriodicOnIndexCrossReals {}

    public interface OnNonNegativeIntegersCrossIndex
        extends OnSubsetOfIntegersCrossIntegers,
        Domain.OnNonNegativeIntegersCrossIndex {}

    public interface OnNonNegativeIntegersCrossIntegers
        extends OnSubsetOfIntegersCrossIntegers,
        Domain.OnNonNegativeIntegersCrossIntegers {}

    public interface PeriodicOnNonNegativeIntegersCrossIntegers
        extends OnSubsetOfIntegersCrossIntegers,
        Domain.PeriodicOnNonNegativeIntegersCrossIntegers {}

    public interface OnNonNegativeIntegersCrossInterval
        extends OnSubsetOfIntegersCrossReals,
        Domain.OnNonNegativeIntegersCrossInterval {}

    public interface OnNonNegativeIntegersCrossReals
        extends OnSubsetOfIntegersCrossReals,
        Domain.OnNonNegativeIntegersCrossReals {}

    public interface PeriodicOnNonNegativeIntegersCrossReals
        extends OnSubsetOfIntegersCrossReals,
        Domain.PeriodicOnNonNegativeIntegersCrossReals {}

    public interface OnIntegersCrossIndex
        extends OnNonNegativeIntegersCrossIndex {}

    public interface OnIntegersCrossIntegers
        extends OnNonNegativeIntegersCrossIntegers {}

    public interface PeriodicOnIntegersCrossIntegers
        extends PeriodicOnNonNegativeIntegersCrossIntegers {}

    public interface DoublyPeriodicOnIntegersCrossIntegers
        extends PeriodicOnIntegersCrossIntegers,
        Domain.DoublyPeriodicOnIntegersCrossIntegers {}

    public interface OnIntegersCrossInterval
        extends OnNonNegativeIntegersCrossInterval {}

    public interface OnIntegersCrossReals
        extends OnNonNegativeIntegersCrossReals {}

    public interface PeriodicOnIntegersCrossReals
        extends OnIntegersCrossReals, Domain.PeriodicOnIntegersCrossReals {}

    public interface OnIntervalCrossIndex
        extends OnSubsetOfRealsCrossIntegers, Domain.OnIntervalCrossIndex {}

    public interface OnIntervalCrossIntegers
        extends OnSubsetOfRealsCrossIntegers, Domain.OnIntervalCrossIntegers {}

    public interface PeriodicOnIntervalCrossIntegers
        extends OnIntervalCrossIntegers,
        Domain.PeriodicOnIntervalCrossIntegers {}

    public interface OnIntervalCrossInterval
        extends OnSubsetOfRealsCrossReals, Domain.OnIntervalCrossInterval {}

    public interface OnIntervalCrossReals
        extends OnSubsetOfRealsCrossReals, Domain.OnIntervalCrossReals {}

    public interface PeriodicOnIntervalCrossReals
        extends OnIntervalCrossReals, Domain.PeriodicOnIntervalCrossReals {}

    public interface OnNonNegativeRealsCrossIndex
        extends OnSubsetOfRealsCrossIntegers,
        Domain.OnNonNegativeRealsCrossIndex {}

    public interface OnNonNegativeRealsCrossIntegers
        extends OnSubsetOfRealsCrossIntegers,
        Domain.OnNonNegativeRealsCrossIntegers {}

    public interface PeriodicOnNonNegativeRealsCrossIntegers
        extends OnNonNegativeRealsCrossIntegers,
        Domain.PeriodicOnNonNegativeRealsCrossIntegers {}

    public interface OnNonNegativeRealsCrossInterval
        extends OnSubsetOfRealsCrossReals,
        Domain.OnNonNegativeRealsCrossInterval {}

    public interface OnNonNegativeRealsCrossReals
        extends OnSubsetOfRealsCrossReals,
        Domain.OnNonNegativeRealsCrossReals {}

    public interface PeriodicOnNonNegativeRealsCrossReals
        extends OnNonNegativeRealsCrossReals,
        Domain.PeriodicOnNonNegativeRealsCrossReals {}

    public interface OnRealsCrossIndex
        extends OnNonNegativeRealsCrossIndex {}

    public interface OnRealsCrossIntegers
        extends OnNonNegativeRealsCrossIntegers {}

    public interface PeriodicOnRealsCrossIntegers
        extends PeriodicOnNonNegativeRealsCrossIntegers {}

    public interface OnRealsCrossInterval
        extends OnNonNegativeRealsCrossInterval {}

    public interface OnRealsCrossReals
        extends OnNonNegativeRealsCrossReals {}

    public interface PeriodicOnRealsCrossReals
        extends PeriodicOnNonNegativeRealsCrossReals {}

    public interface DoublyPeriodicOnRealsCrossReals
        extends PeriodicOnRealsCrossReals,
        Domain.DoublyPeriodicOnRealsCrossReals {}

    public interface OnIndexCrossIndexCrossIndex
        extends OnSubsetOfIntegersCrossIntegersCrossIntegers,
        Domain.OnIndexCrossIndexCrossIndex {}

    public interface OnIndexCrossIntegersCrossIntegers
        extends OnSubsetOfIntegersCrossIntegersCrossIntegers,
        Domain.OnIndexCrossIntegersCrossIntegers {}

    public interface DoublyPeriodicOnIndexCrossIntegersCrossIntegers
        extends OnSubsetOfIntegersCrossIntegersCrossIntegers,
        Domain.DoublyPeriodicOnIndexCrossIntegersCrossIntegers {}

    public interface OnNonNegativeIntegersCrossIndexCrossIndex
        extends OnSubsetOfIntegersCrossIntegersCrossIntegers,
        Domain.OnNonNegativeIntegersCrossIndexCrossIndex {}

    public interface OnNonNegativeIntegersCrossIntegersCrossIntegers
        extends OnSubsetOfIntegersCrossIntegersCrossIntegers,
        Domain.OnNonNegativeIntegersCrossIntegersCrossIntegers {}

    public interface DoublyPeriodicOnNonNegativeIntegersCrossIntegersCrossIntegers
        extends OnSubsetOfIntegersCrossIntegersCrossIntegers,
        Domain.DoublyPeriodicOnNonNegativeIntegersCrossIntegersCrossIntegers {}

    public interface OnIntegersCrossIndexCrossIndex
        extends OnNonNegativeIntegersCrossIndexCrossIndex,
        Domain.OnIntegersCrossIndexCrossIndex {}

    public interface OnIntegersCrossIntegersCrossIntegers
        extends OnNonNegativeIntegersCrossIntegersCrossIntegers,
        Domain.OnIntegersCrossIntegersCrossIntegers {}

    public interface DoublyPeriodicOnIntegersCrossIntegersCrossIntegers
        extends OnIntegersCrossIntegersCrossIntegers,
        Domain.DoublyPeriodicOnIntegersCrossIntegersCrossIntegers {}

    public interface TriplyPeriodicOnIntegersCrossIntegersCrossIntegers
        extends DoublyPeriodicOnIntegersCrossIntegersCrossIntegers,
        Domain.TriplyPeriodicOnIntegersCrossIntegersCrossIntegers {}

    public interface OnIntervalCrossIntervalCrossInterval
        extends OnSubsetOfRealsCrossRealsCrossReals,
        Domain.OnIntervalCrossIntervalCrossInterval {}

    public interface OnIntervalCrossRealsCrossReals
        extends OnSubsetOfRealsCrossRealsCrossReals,
        Domain.OnIntervalCrossRealsCrossReals {}

    public interface DoublyPeriodicOnIntervalCrossRealsCrossReals
        extends OnSubsetOfRealsCrossRealsCrossReals,
        Domain.DoublyPeriodicOnIntervalCrossRealsCrossReals {}

    public interface OnNonNegativeRealsCrossIntervalCrossInterval
        extends OnSubsetOfRealsCrossRealsCrossReals,
        Domain.OnNonNegativeRealsCrossIntervalCrossInterval {}

    public interface OnNonNegativeRealsCrossRealsCrossReals
        extends OnSubsetOfRealsCrossRealsCrossReals,
        Domain.OnNonNegativeRealsCrossRealsCrossReals {}

    public interface DoublyPeriodicOnNonNegativeRealsCrossRealsCrossReals
        extends OnSubsetOfRealsCrossRealsCrossReals,
        Domain.DoublyPeriodicOnNonNegativeRealsCrossRealsCrossReals {}

    public interface OnRealsCrossIntervalCrossInterval
        extends OnNonNegativeRealsCrossIntervalCrossInterval,
        Domain.OnRealsCrossIntervalCrossInterval {}

    public interface OnRealsCrossRealsCrossReals
        extends OnNonNegativeRealsCrossRealsCrossReals,
        Domain.OnRealsCrossRealsCrossReals {}

    public interface DoublyPeriodicOnRealsCrossRealsCrossReals
        extends DoublyPeriodicOnNonNegativeRealsCrossRealsCrossReals,
        Domain.DoublyPeriodicOnRealsCrossRealsCrossReals {}

    public interface TriplyPeriodicOnRealsCrossRealsCrossReals
        extends DoublyPeriodicOnRealsCrossReals,
        Domain.TriplyPeriodicOnRealsCrossRealsCrossReals {}
}